from django.contrib.auth.models import User
from django.contrib import admin
from django.contrib.sessions.models import Session
from django.conf import settings
from django.contrib.auth.admin import UserAdmin


 



class HijackUserAdmin(UserAdmin):
    list_display = ('username', 'email', 'first_name', 'last_name',  'last_login', 'date_joined', 'is_staff', 'hijack_field',)
    list_filter = ('is_staff', 'is_superuser')
    search_fields = ('username', 'first_name', 'last_name', 'email',)

    def hijack_field(self, obj):
        return '<a href="/hijack/%s" class="button">Hijack %s</a>' % (obj.id, obj.username)
    hijack_field.allow_tags = True
    hijack_field.short_description = 'Hijack User'

admin.site.unregister(User)
admin.site.register(User, HijackUserAdmin)


class SessionAdmin(admin.ModelAdmin):
    def _session_data(self, obj):
        return obj.get_decoded()
    list_display = ['session_key', '_session_data', 'expire_date']

if getattr(settings, "SHOW_SESSIONS_IN_ADMIN", False):
    admin.site.register(Session, SessionAdmin)



from django.contrib.admin.views.decorators import staff_member_required
from django.contrib.auth.models import User
from django.shortcuts import get_object_or_404

from helpers import login_user

@staff_member_required
def login_with_id(request, userId):
    user = get_object_or_404(User, pk=userId)
    return login_user(request, user)

@staff_member_required
def login_with_email(request, email):
    user = get_object_or_404(User, email=email)
    return login_user(request, user)

@staff_member_required
def login_with_username(request, username):
    user = get_object_or_404(User, username=username)
    return login_user(request, user)



from django.http import HttpResponse, Http404, HttpResponseRedirect
from django.conf import settings
from django.contrib.auth import login, get_backends
from django.core.exceptions import PermissionDenied

def login_user(request, user):
    if not request.user.is_superuser:
        raise PermissionDenied
    backend = get_backends()[0]
    user.backend = "%s.%s" % (backend.__module__, backend.__class__.__name__)
    login(request, user)
    return HttpResponseRedirect(getattr(settings, "LOGIN_REDIRECT_URL", "/"))



"""URLs for the hijack app."""
from django.conf.urls.defaults import patterns, url

# from . import views

urlpatterns = patterns('hijack.views',
    url(r'^email/(?P<email>[\w.%+-]+@[A-Za-z0-9.-]+\.[A-Za-z]{2,4})/$', 'login_with_email'),
    url(r'^username/(?P<username>\w+)/$', 'login_with_username'),
    url(r'^(?P<userId>\w+)/$', 'login_with_id'),
)
